@@ -37,7 +37,7 @@ from glchess.defaults import *
 # It should really just throw ImportError
 try:
     import gtk.gtkgl
-    import OpenGL
+    import OpenGL.GL
 except (ImportError, RuntimeError):
     haveGLSupport = False
 else:
@@ -75,10 +75,6 @@ class GtkViewArea(gtk.DrawingArea):
         
         self.view = view
 
-        if haveGnomeSupport:
-            gnome.program_init('glchess', VERSION,
-                               properties={gnome.PARAM_APP_DATADIR: APP_DATA_DIR})
-
         # Allow notification of button presses
         self.add_events(gtk.gdk.BUTTON_PRESS_MASK | gtk.gdk.BUTTON_RELEASE_MASK | gtk.gdk.BUTTON_MOTION_MASK)
         
@@ -133,11 +129,15 @@ class GtkViewArea(gtk.DrawingArea):
         self.__glDrawable = glDrawable
 
         if not self.view.ui.openGLInfoPrinted:
+            vendor     = OpenGL.GL.glGetString(OpenGL.GL.GL_VENDOR)
+            renderer   = OpenGL.GL.glGetString(OpenGL.GL.GL_RENDERER)
+            version    = OpenGL.GL.glGetString(OpenGL.GL.GL_VERSION)
+            extensions = OpenGL.GL.glGetString(OpenGL.GL.GL_EXTENSIONS)
             print 'Using OpenGL:'
-            print 'VENDOR=' + OpenGL.GL.glGetString(OpenGL.GL.GL_VENDOR)
-            print 'RENDERER=' + OpenGL.GL.glGetString(OpenGL.GL.GL_RENDERER)
-            print 'VERSION=' + OpenGL.GL.glGetString(OpenGL.GL.GL_VERSION)
-            print 'EXTENSIONS=' + OpenGL.GL.glGetString(OpenGL.GL.GL_EXTENSIONS)
+            print 'VENDOR=%s' % vendor
+            print 'RENDERER=%s' % renderer
+            print 'VERSION=%s' % version
+            print 'EXTENSIONS=%s' % extensions
             self.view.ui.openGLInfoPrinted = True
         
     def __endGL(self):
@@ -172,7 +172,7 @@ class GtkViewArea(gtk.DrawingArea):
             try:
                 if self.view.feedback is not None:
                     self.view.feedback.renderGL()
-            except OpenGL.GLerror, e:
+            except OpenGL.GL.GLerror, e:
                 print 'Rendering Error: ' + str(e)
                 traceback.print_exc(file = sys.stdout)
 
@@ -276,13 +276,24 @@ class GtkView(glchess.ui.ViewController):
             self.ui._incAttentionCounter(-1)
 
     def addMove(self, move):
-        """Extends glchess.ui.ViewController"""
+        """Extends glchess.ui.ViewController
+	Based on the current move, this method creates a string
+	describing the move, and displays it in the GUI.
+	"""
         # FIXME: Make a '@ui' player who watches for these itself?
         iter = self.moveModel.append()
         string = '%2i. ' % ((move.number - 1) / 2 + 1)
         if move.number % 2 == 0:
             string += '... '
         string += move.sanMove
+
+        if move.result is glchess.chess.board.MOVE_RESULT_OPPONENT_CHECK:
+            string += " - " + gettext.gettext('Check')
+        if move.result is glchess.chess.board.MOVE_RESULT_OPPONENT_CHECKMATE:
+            string += " - " + gettext.gettext('Checkmate, %s wins.' % (move.player.getName()))
+        if move.result is glchess.chess.board.MOVE_RESULT_STALEMATE:
+            string += ' - Stalemate, draw.'
+
         self.moveModel.set(iter, 0, move.number, 1, string)
         
         # If is the current view and tracking the game select this
@@ -540,6 +551,9 @@ class GtkUI(glchess.ui.UI):
     # The time stored for animation
     __lastTime         = None
     __animationTimer   = None
+    
+    # Timers
+    timers             = None
 
     # The notebook containing games
     notebook           = None
@@ -567,6 +581,10 @@ class GtkUI(glchess.ui.UI):
 
     def __init__(self):
         """Constructor for a GTK+ glChess GUI"""
+        if haveGnomeSupport:
+            gnome.program_init('glchess', VERSION,
+                               properties={gnome.PARAM_APP_DATADIR: APP_DATA_DIR})
+        
         self.__networkGames = {}
         self.__saveGameDialogs = {}
         self.__joinGameDialogs = []
@@ -620,7 +638,21 @@ class GtkUI(glchess.ui.UI):
     
     def watchFileDescriptor(self, fd):
         """Extends ui.UI"""
-        gobject.io_add_watch(fd, gobject.IO_IN, self.__readData)
+        gobject.io_add_watch(fd, gobject.IO_IN | gobject.IO_HUP, self.__readData)
+        
+    def addTimer(self, method, timeUsec):
+        """Extends ui.UI"""
+        timer = gobject.timeout_add(timeUsec / 1000, self.__timerExpired, method)
+        self.timers[method] = timer
+
+    def __timerExpired(self, method):
+        method()
+        return True
+
+    def removeTimer(self, method):
+        """Extends ui.UI"""
+        timer = self.timers.pop(method)
+        gobject.source_remove(timer)
 
     def __readData(self, fd, condition):
         return self.onReadFileDescriptor(fd)
@@ -705,7 +737,7 @@ class GtkUI(glchess.ui.UI):
         # Update the open dialogs
         for dialog in self.__joinGameDialogs:
             dialog.addNetworkGame(name, game)
-    
+
     def removeNetworkGame(self, game):
         """Extends glchess.ui.UI"""
         self.__networkGames.pop(game)
@@ -1018,7 +1050,10 @@ class GtkUI(glchess.ui.UI):
 
     def _on_help_clicked(self, widget, data = None):
         """Gtk+ callback"""
-        gnome.help_display('glchess')
+        try:
+            gnome.help_display('glchess')
+        except gobject.GError, e:
+            print 'Unable to display help: %s' % str(e)
 
     def _on_view_fullscreen_clicked(self, widget, data = None):
         """Gtk+ callback"""
@@ -1049,7 +1084,7 @@ class GtkUI(glchess.ui.UI):
         dialog.set_name(APPNAME)
         dialog.set_version(VERSION)
         dialog.set_copyright(COPYRIGHT)
-        dialog.set_license(LICENSE)
+        dialog.set_license(LICENSE[0] + '\n\n' + LICENSE[1] + '\n\n' +LICENSE[2])
         dialog.set_wrap_license(True)
         dialog.set_comments(DESCRIPTION)
         dialog.set_authors(AUTHORS)
